﻿using Hotline.Share.Enums.FlowEngine;

namespace Hotline.Share.Dtos.FlowEngine.Workflow
{
    public class StepBasicDto
    {
        public string WorkflowId { get; set; }

        /// <summary>
        /// 该节点指派办理对象（依据不同指派方式可能为：orgId或userId）,该字段subStep才会存在，stepBox不存在
        /// 采用list类型，兼容多个办理对象可以办理同一个节点的场景
        /// </summary>
        public List<Kv> Handlers { get; set; } = new();

        /// <summary>
        /// 办理时间限制(如：24小时、7个工作日)
        /// </summary>
        public string? TimeLimit { get; set; }

        /// <summary>
        /// 上一节点办理时，nextStepCode下拉框中选中的值
        /// config模式：当前节点的difinition.code, dynamic模式：x级部门办理的x：int
        /// </summary>
        public string? PrevChosenStepCode { get; set; }

        #region 接办

        /// <summary>
        /// 接办人
        /// </summary>
        public string? AcceptorId { get; set; }

        public string? AcceptorName { get; set; }

        /// <summary>
        /// 接办人部门code
        /// </summary>
        public string? AcceptorOrgId { get; set; }

        public string? AcceptorOrgName { get; set; }

        /// <summary>
        /// 接办人部门行政区划代码
        /// </summary>
        public string? AcceptorOrgAreaCode { get; set; }

        /// <summary>
        /// 接办人部门行政区划名称
        /// </summary>
        public string? AcceptorOrgAreaName { get; set; }

        /// <summary>
        /// 接办时间
        /// </summary>
        public DateTime? AcceptTime { get; set; }

        #endregion

        #region 办理

        /// <summary>
        /// 办理人
        /// </summary>
        public string? HandlerId { get; set; }

        public string? HandlerName { get; set; }

        /// <summary>
        /// 办理人部门code
        /// </summary>
        public string? HandlerOrgId { get; set; }

        /// <summary>
        /// 办理人部门名称
        /// </summary>
        public string? HandlerOrgName { get; set; }

        /// <summary>
        /// 办理人部门行政区划代码
        /// </summary>
        public string? HandlerOrgAreaCode { get; set; }

        /// <summary>
        /// 办理人部门行政区划名称
        /// </summary>
        public string? HandlerOrgAreaName { get; set; }

        /// <summary>
        /// 办理完成时间
        /// </summary>
        public DateTime? HandleTime { get; set; }

        #endregion

        #region 办理参数

        /// <summary>
        /// (下一节点办理人)根据审批者类型不同，此字段为不同内容
        /// <example>
        /// 部门等级/分类为：orgCodes, 角色为：userIds
        /// </example>
        /// </summary>
        public List<Kv> NextHandlers { get; set; } = new();

        /// <summary>
        /// 下一节点主办，(NextHandlers其中一个, 如果不是会签则只有一个)
        /// </summary>
        public string? NextMainHandler { get; set; }

        /// <summary>
        /// 下一节点code（stepBox无值）
        /// </summary>
        public string? NextStepCode { get; set; }

        /// <summary>
        /// 是否回到会签发起节点汇总
        /// </summary>
        public bool BackToCountersignEnd { get; set; }

        /// <summary>
        /// 是否短信通知
        /// </summary>
        public bool IsSms { get; set; }

        /// <summary>
        /// 办理意见
        /// </summary>
        public string? Opinion { get; set; }

        /// <summary>
        /// 附件
        /// </summary>
        public List<string> Additions { get; set; } = new();

        /// <summary>
        /// 节点期满时间
        /// </summary>
        public DateTime? StepExpiredTime { get; set; }

        #endregion

    }
}
