﻿using Hotline.Share.Dtos.FlowEngine.Definition;
using Hotline.Share.Enums.FlowEngine;

namespace Hotline.Share.Dtos.FlowEngine.Workflow;

public class WorkflowStepDto
{
    public string Id { get; set; }

    public DateTime CreationTime { get; set; }

    /// <summary>
    /// 配置下一步节点 & 谁被选中
    /// </summary>
    public List<StepSimple> NextSteps { get; set; } = new();

    /// <summary>
    /// 前一级节点Id(stepBox此字段为上级stepBoxId,step为上级stepId),汇总节点无此字段（因可能有多个上级来源）
    /// </summary>
    public string? PrevStepId { get; set; }
    public string? PrevStepCode { get; set; }

    /// <summary>
    /// 主办
    /// </summary>
    public bool IsMain { get; set; }

    /// <summary>
    /// 节点办理状态
    /// </summary>
    public EWorkflowStepStatus Status { get; set; }

    /// <summary>
    /// 原生节点（区别动态生成）
    /// </summary>
    public bool IsOrigin { get; set; }


    #region 会签
    
    /// <summary>
    /// 会签id（或外层会签的id）
    /// </summary>
    public string? CountersignId { get; set; }

    /// <summary>
    /// 节点处于会签流程中的位置（区别直接办理会签和会签内非会签节点）
    /// 最顶层的发起会签节点为none
    /// </summary>
    public ECountersignPosition CountersignPosition { get; set; }

    #region 发起会签节点特有

    /// <summary>
    /// 发起会签生成会签Id（不发起会签节点无此字段）
    /// </summary>
    public string? StartCountersignId { get; set; }

    /// <summary>
    /// 会签直属办理节点
    /// </summary>
    public List<CountersignStep> CountersignSteps { get; set; } = new();

    /// <summary>
    /// 发起的会签是否汇总
    /// </summary>
    public bool IsStartedCountersignEnd { get; set; }

    #endregion

    #region 会签汇总节点特有

    /// <summary>
    /// 是否为会签汇总节点
    /// </summary>
    public bool IsCountersignEndStep { get; set; }

    /// <summary>
    /// 开启会签节点id（会签汇总节点对应会签发起节点id）
    /// </summary>
    public string? CountersignStartStepId { get; set; }

    #endregion

    #endregion

    #region Definition

    public string Name { get; set; }

    /// <summary>
    /// 模板内唯一
    /// </summary>
    public string Code { get; set; }

    public EStepType StepType { get; init; }

    /// <summary>
    /// 节点业务类型
    /// </summary>
    public EBusinessType BusinessType { get; set; }

    /// <summary>
    /// 办理人类型
    /// </summary>
    public EHandlerType HandlerType { get; set; }

    /// <summary>
    /// 是否有否决按钮
    /// </summary>
    public bool CanReject { get; set; }

    /// <summary>
    /// 执行模式(自动与否)
    /// 只有普通节点支持自动，会签、动态节点均不支持自动
    /// </summary>
    public EExecuteMode ExecuteMode { get; set; }

    #region 会签相关配置

    /// <summary>
    /// 是否支持发起会签（即使支持发起，当下一节点为汇总或结束节点时亦不可发起）
    /// </summary>
    public bool CanStartCountersign { get; set; }

    /// <summary>
    /// 会签策略
    /// </summary>
    public EDynamicPolicy? CountersignPolicy { get; set; }

    #endregion

    #region 依据配置生成节点的方式

    /// <summary>
    /// 实例化模式
    /// </summary>
    public EInstanceMode InstanceMode { get; set; }

    /// <summary>
    /// 动态实例化策略(多次模式才有)
    /// </summary>
    public EDynamicPolicy? InstancePolicy { get; set; }

    /// <summary>
    /// 到此标记终止动态实例化(多次模式才有)
    /// <remarks>
    /// 按直属部门重复既保存orgLevel:int
    /// </remarks>
    /// </summary>
    public string? TerminalDynamicMark { get; set; }

    #endregion

    /// <summary>
    /// 标签
    /// </summary>
    public string? Tag { get; set; }

    #endregion
}